From 387289e3e5ac32024b9a5ab3edcb0aece4afc645 Mon Sep 17 00:00:00 2001
From: Daniel Gustafsson <daniel@yesql.se>
Date: Mon, 19 Mar 2018 13:12:16 +0100
Subject: [PATCH] Align error messaging with project style guide

Details and hints should have leading capitalization, have double
spaces after punctuation and should end with period. Context should
not be capitalized and should not end with period. Also update test
.out files to match.
---
 contrib/dblink/dblink.c                            |  6 ++--
 contrib/dblink/expected/dblink.out                 | 24 ++++++++--------
 contrib/earthdistance/expected/earthdistance.out   |  8 +++---
 contrib/file_fdw/file_fdw.c                        |  4 +--
 contrib/pgcrypto/px.c                              |  4 +--
 contrib/postgres_fdw/connection.c                  |  2 +-
 contrib/postgres_fdw/expected/postgres_fdw.out     | 14 +++++-----
 contrib/postgres_fdw/option.c                      |  2 +-
 doc/src/sgml/typeconv.sgml                         |  4 +--
 src/backend/access/gist/gistsplit.c                |  2 +-
 src/backend/access/nbtree/nbtpage.c                |  2 +-
 src/backend/access/transam/xlog.c                  |  2 +-
 src/backend/commands/copy.c                        |  8 +++---
 src/backend/parser/analyze.c                       |  2 +-
 src/backend/parser/parse_func.c                    |  6 ++--
 src/backend/parser/parse_oper.c                    |  6 ++--
 src/backend/replication/logical/logical.c          |  2 +-
 src/backend/tcop/postgres.c                        |  2 +-
 src/pl/plperl/expected/plperl_elog.out             |  2 +-
 src/pl/plperl/expected/plperl_elog_1.out           |  2 +-
 src/pl/plpgsql/src/expected/plpgsql_record.out     |  2 +-
 src/pl/plpython/expected/plpython_error.out        |  2 +-
 src/pl/plpython/expected/plpython_error_0.out      |  2 +-
 src/pl/plpython/expected/plpython_error_5.out      |  2 +-
 .../expected/plpython_subtransaction_0.out         | 30 ++++++++++----------
 .../expected/plpython_subtransaction_5.out         | 30 ++++++++++----------
 src/test/regress/expected/alter_table.out          |  2 +-
 src/test/regress/expected/arrays.out               |  2 +-
 src/test/regress/expected/create_cast.out          |  4 +--
 src/test/regress/expected/create_procedure.out     |  2 +-
 src/test/regress/expected/create_view.out          |  2 +-
 src/test/regress/expected/domain.out               |  2 +-
 src/test/regress/expected/geometry.out             |  2 +-
 src/test/regress/expected/geometry_1.out           |  2 +-
 src/test/regress/expected/geometry_2.out           |  2 +-
 src/test/regress/expected/horology.out             |  2 +-
 src/test/regress/expected/misc_functions.out       |  4 +--
 src/test/regress/expected/plpgsql.out              |  2 +-
 src/test/regress/expected/polymorphism.out         | 32 +++++++++++-----------
 src/test/regress/expected/rangetypes.out           |  4 +--
 src/test/regress/expected/rowtypes.out             |  4 +--
 src/test/regress/expected/text.out                 |  4 +--
 src/test/regress/expected/time.out                 |  2 +-
 src/test/regress/expected/timetz.out               |  2 +-
 src/test/regress/expected/with.out                 |  2 +-
 45 files changed, 125 insertions(+), 125 deletions(-)

diff --git a/contrib/dblink/dblink.c b/contrib/dblink/dblink.c
index ae7e24ad08..e55c9993b6 100644
--- a/contrib/dblink/dblink.c
+++ b/contrib/dblink/dblink.c
@@ -1980,7 +1980,7 @@ dblink_fdw_validator(PG_FUNCTION_ARGS)
 			ereport(ERROR,
 					(errcode(ERRCODE_FDW_OUT_OF_MEMORY),
 					 errmsg("out of memory"),
-					 errdetail("could not get libpq's default connection options")));
+					 errdetail("Could not get libpq's default connection options.")));
 	}
 
 	/* Validate each supplied option. */
@@ -2733,7 +2733,7 @@ dblink_res_error(PGconn *conn, const char *conname, PGresult *res,
 			 message_detail ? errdetail_internal("%s", message_detail) : 0,
 			 message_hint ? errhint("%s", message_hint) : 0,
 			 message_context ? errcontext("%s", message_context) : 0,
-			 errcontext("Error occurred on dblink connection named \"%s\": %s.",
+			 errcontext("error occurred on dblink connection named \"%s\": %s",
 						dblink_context_conname, dblink_context_msg)));
 }
 
@@ -2769,7 +2769,7 @@ get_connect_string(const char *servername)
 			ereport(ERROR,
 					(errcode(ERRCODE_FDW_OUT_OF_MEMORY),
 					 errmsg("out of memory"),
-					 errdetail("could not get libpq's default connection options")));
+					 errdetail("Could not get libpq's default connection options.")));
 	}
 
 	/* first gather the server connstr options */
diff --git a/contrib/dblink/expected/dblink.out b/contrib/dblink/expected/dblink.out
index 511691e57f..c4702ee00d 100644
--- a/contrib/dblink/expected/dblink.out
+++ b/contrib/dblink/expected/dblink.out
@@ -155,7 +155,7 @@ WHERE t.a > 7;
 -- open a cursor with bad SQL and fail_on_error set to false
 SELECT dblink_open('rmt_foo_cursor','SELECT * FROM foobar',false);
 NOTICE:  relation "foobar" does not exist
-CONTEXT:  Error occurred on dblink connection named "unnamed": could not open cursor.
+CONTEXT:  error occurred on dblink connection named "unnamed": could not open cursor
  dblink_open 
 -------------
  ERROR
@@ -223,7 +223,7 @@ FROM dblink_fetch('rmt_foo_cursor',4) AS t(a int, b text, c text[]);
 SELECT *
 FROM dblink_fetch('rmt_foobar_cursor',4,false) AS t(a int, b text, c text[]);
 NOTICE:  cursor "rmt_foobar_cursor" does not exist
-CONTEXT:  Error occurred on dblink connection named "unnamed": could not fetch from cursor.
+CONTEXT:  error occurred on dblink connection named "unnamed": could not fetch from cursor
  a | b | c 
 ---+---+---
 (0 rows)
@@ -238,7 +238,7 @@ SELECT dblink_exec('ABORT');
 -- close the wrong cursor
 SELECT dblink_close('rmt_foobar_cursor',false);
 NOTICE:  cursor "rmt_foobar_cursor" does not exist
-CONTEXT:  Error occurred on dblink connection named "unnamed": could not close cursor.
+CONTEXT:  error occurred on dblink connection named "unnamed": could not close cursor
  dblink_close 
 --------------
  ERROR
@@ -248,12 +248,12 @@ CONTEXT:  Error occurred on dblink connection named "unnamed": could not close c
 SELECT *
 FROM dblink_fetch('rmt_foo_cursor',4) AS t(a int, b text, c text[]);
 ERROR:  cursor "rmt_foo_cursor" does not exist
-CONTEXT:  Error occurred on dblink connection named "unnamed": could not fetch from cursor.
+CONTEXT:  error occurred on dblink connection named "unnamed": could not fetch from cursor
 -- this time, 'cursor "rmt_foo_cursor" not found' as a notice
 SELECT *
 FROM dblink_fetch('rmt_foo_cursor',4,false) AS t(a int, b text, c text[]);
 NOTICE:  cursor "rmt_foo_cursor" does not exist
-CONTEXT:  Error occurred on dblink connection named "unnamed": could not fetch from cursor.
+CONTEXT:  error occurred on dblink connection named "unnamed": could not fetch from cursor
  a | b | c 
 ---+---+---
 (0 rows)
@@ -316,7 +316,7 @@ FROM dblink('SELECT * FROM foo') AS t(a int, b text, c text[]);
 SELECT *
 FROM dblink('SELECT * FROM foobar',false) AS t(a int, b text, c text[]);
 NOTICE:  relation "foobar" does not exist
-CONTEXT:  Error occurred on dblink connection named "unnamed": could not execute query.
+CONTEXT:  error occurred on dblink connection named "unnamed": could not execute query
  a | b | c 
 ---+---+---
 (0 rows)
@@ -340,7 +340,7 @@ WHERE a = 11;
 -- botch a change to some other data
 SELECT dblink_exec('UPDATE foobar SET f3[2] = ''b99'' WHERE f1 = 11',false);
 NOTICE:  relation "foobar" does not exist
-CONTEXT:  Error occurred on dblink connection named "unnamed": could not execute command.
+CONTEXT:  error occurred on dblink connection named "unnamed": could not execute command
  dblink_exec 
 -------------
  ERROR
@@ -400,7 +400,7 @@ SELECT *
 FROM dblink('myconn','SELECT * FROM foobar',false) AS t(a int, b text, c text[])
 WHERE t.a > 7;
 NOTICE:  relation "foobar" does not exist
-CONTEXT:  Error occurred on dblink connection named "myconn": could not execute query.
+CONTEXT:  error occurred on dblink connection named "myconn": could not execute query
  a | b | c 
 ---+---+---
 (0 rows)
@@ -437,7 +437,7 @@ SELECT dblink_disconnect('myconn2');
 -- open a cursor incorrectly
 SELECT dblink_open('myconn','rmt_foo_cursor','SELECT * FROM foobar',false);
 NOTICE:  relation "foobar" does not exist
-CONTEXT:  Error occurred on dblink connection named "myconn": could not open cursor.
+CONTEXT:  error occurred on dblink connection named "myconn": could not open cursor
  dblink_open 
 -------------
  ERROR
@@ -523,7 +523,7 @@ SELECT dblink_close('myconn','rmt_foo_cursor');
 -- this should fail because there is no open transaction
 SELECT dblink_exec('myconn','DECLARE xact_test CURSOR FOR SELECT * FROM foo');
 ERROR:  DECLARE CURSOR can only be used in transaction blocks
-CONTEXT:  Error occurred on dblink connection named "myconn": could not execute command.
+CONTEXT:  error occurred on dblink connection named "myconn": could not execute command
 -- reset remote transaction state
 SELECT dblink_exec('myconn','ABORT');
  dblink_exec 
@@ -573,7 +573,7 @@ FROM dblink_fetch('myconn','rmt_foo_cursor',4) AS t(a int, b text, c text[]);
 SELECT *
 FROM dblink_fetch('myconn','rmt_foobar_cursor',4,false) AS t(a int, b text, c text[]);
 NOTICE:  cursor "rmt_foobar_cursor" does not exist
-CONTEXT:  Error occurred on dblink connection named "myconn": could not fetch from cursor.
+CONTEXT:  error occurred on dblink connection named "myconn": could not fetch from cursor
  a | b | c 
 ---+---+---
 (0 rows)
@@ -589,7 +589,7 @@ SELECT dblink_exec('myconn','ABORT');
 SELECT *
 FROM dblink_fetch('myconn','rmt_foo_cursor',4) AS t(a int, b text, c text[]);
 ERROR:  cursor "rmt_foo_cursor" does not exist
-CONTEXT:  Error occurred on dblink connection named "myconn": could not fetch from cursor.
+CONTEXT:  error occurred on dblink connection named "myconn": could not fetch from cursor
 -- close the named persistent connection
 SELECT dblink_disconnect('myconn');
  dblink_disconnect 
diff --git a/contrib/earthdistance/expected/earthdistance.out b/contrib/earthdistance/expected/earthdistance.out
index 89022491cb..74156600e6 100644
--- a/contrib/earthdistance/expected/earthdistance.out
+++ b/contrib/earthdistance/expected/earthdistance.out
@@ -886,7 +886,7 @@ SELECT is_point(ll_to_earth(0,0));
 ERROR:  function is_point(earth) does not exist
 LINE 1: SELECT is_point(ll_to_earth(0,0));
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT cube_dim(ll_to_earth(0,0)) <= 3;
  ?column? 
 ----------
@@ -904,7 +904,7 @@ SELECT is_point(ll_to_earth(30,60));
 ERROR:  function is_point(earth) does not exist
 LINE 1: SELECT is_point(ll_to_earth(30,60));
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT cube_dim(ll_to_earth(30,60)) <= 3;
  ?column? 
 ----------
@@ -922,7 +922,7 @@ SELECT is_point(ll_to_earth(60,90));
 ERROR:  function is_point(earth) does not exist
 LINE 1: SELECT is_point(ll_to_earth(60,90));
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT cube_dim(ll_to_earth(60,90)) <= 3;
  ?column? 
 ----------
@@ -940,7 +940,7 @@ SELECT is_point(ll_to_earth(-30,-90));
 ERROR:  function is_point(earth) does not exist
 LINE 1: SELECT is_point(ll_to_earth(-30,-90));
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT cube_dim(ll_to_earth(-30,-90)) <= 3;
  ?column? 
 ----------
diff --git a/contrib/file_fdw/file_fdw.c b/contrib/file_fdw/file_fdw.c
index dce3be2617..3df6fc741d 100644
--- a/contrib/file_fdw/file_fdw.c
+++ b/contrib/file_fdw/file_fdw.c
@@ -277,7 +277,7 @@ file_fdw_validator(PG_FUNCTION_ARGS)
 				ereport(ERROR,
 						(errcode(ERRCODE_SYNTAX_ERROR),
 						 errmsg("conflicting or redundant options"),
-						 errhint("option \"force_not_null\" supplied more than once for a column")));
+						 errhint("Option \"force_not_null\" supplied more than once for a column.")));
 			force_not_null = def;
 			/* Don't care what the value is, as long as it's a legal boolean */
 			(void) defGetBoolean(def);
@@ -289,7 +289,7 @@ file_fdw_validator(PG_FUNCTION_ARGS)
 				ereport(ERROR,
 						(errcode(ERRCODE_SYNTAX_ERROR),
 						 errmsg("conflicting or redundant options"),
-						 errhint("option \"force_null\" supplied more than once for a column")));
+						 errhint("Option \"force_null\" supplied more than once for a column.")));
 			force_null = def;
 			(void) defGetBoolean(def);
 		}
diff --git a/contrib/pgcrypto/px.c b/contrib/pgcrypto/px.c
index 8ec920224a..aea8e863af 100644
--- a/contrib/pgcrypto/px.c
+++ b/contrib/pgcrypto/px.c
@@ -105,8 +105,8 @@ px_THROW_ERROR(int err)
 		ereport(ERROR,
 				(errcode(ERRCODE_FEATURE_NOT_SUPPORTED),
 				 errmsg("generating random data is not supported by this build"),
-				 errdetail("This functionality requires a source of strong random numbers"),
-				 errhint("You need to rebuild PostgreSQL using --enable-strong-random")));
+				 errdetail("This functionality requires a source of strong random numbers."),
+				 errhint("You need to rebuild PostgreSQL using --enable-strong-random.")));
 #endif
 	}
 	else
diff --git a/contrib/postgres_fdw/connection.c b/contrib/postgres_fdw/connection.c
index 00c926b983..fe4893a8e0 100644
--- a/contrib/postgres_fdw/connection.c
+++ b/contrib/postgres_fdw/connection.c
@@ -630,7 +630,7 @@ pgfdw_report_error(int elevel, PGresult *res, PGconn *conn,
 				 message_detail ? errdetail_internal("%s", message_detail) : 0,
 				 message_hint ? errhint("%s", message_hint) : 0,
 				 message_context ? errcontext("%s", message_context) : 0,
-				 sql ? errcontext("Remote SQL command: %s", sql) : 0));
+				 sql ? errcontext("remote SQL command: %s", sql) : 0));
 	}
 	PG_CATCH();
 	{
diff --git a/contrib/postgres_fdw/expected/postgres_fdw.out b/contrib/postgres_fdw/expected/postgres_fdw.out
index a2b13846e0..2d6e387d63 100644
--- a/contrib/postgres_fdw/expected/postgres_fdw.out
+++ b/contrib/postgres_fdw/expected/postgres_fdw.out
@@ -4126,7 +4126,7 @@ FETCH c;
 SAVEPOINT s;
 SELECT * FROM ft1 WHERE 1 / (c1 - 1) > 0;  -- ERROR
 ERROR:  division by zero
-CONTEXT:  Remote SQL command: SELECT "C 1", c2, c3, c4, c5, c6, c7, c8 FROM "S 1"."T 1" WHERE (((1 / ("C 1" - 1)) > 0))
+CONTEXT:  remote SQL command: SELECT "C 1", c2, c3, c4, c5, c6, c7, c8 FROM "S 1"."T 1" WHERE (((1 / ("C 1" - 1)) > 0))
 ROLLBACK TO s;
 FETCH c;
  c1 | c2 |  c3   |              c4              |            c5            | c6 |     c7     | c8  
@@ -5737,7 +5737,7 @@ ALTER TABLE "S 1"."T 1" ADD CONSTRAINT c2positive CHECK (c2 >= 0);
 INSERT INTO ft1(c1, c2) VALUES(11, 12);  -- duplicate key
 ERROR:  duplicate key value violates unique constraint "t1_pkey"
 DETAIL:  Key ("C 1")=(11) already exists.
-CONTEXT:  Remote SQL command: INSERT INTO "S 1"."T 1"("C 1", c2, c3, c4, c5, c6, c7, c8) VALUES ($1, $2, $3, $4, $5, $6, $7, $8)
+CONTEXT:  remote SQL command: INSERT INTO "S 1"."T 1"("C 1", c2, c3, c4, c5, c6, c7, c8) VALUES ($1, $2, $3, $4, $5, $6, $7, $8)
 INSERT INTO ft1(c1, c2) VALUES(11, 12) ON CONFLICT DO NOTHING; -- works
 INSERT INTO ft1(c1, c2) VALUES(11, 12) ON CONFLICT (c1, c2) DO NOTHING; -- unsupported
 ERROR:  there is no unique or exclusion constraint matching the ON CONFLICT specification
@@ -5746,11 +5746,11 @@ ERROR:  there is no unique or exclusion constraint matching the ON CONFLICT spec
 INSERT INTO ft1(c1, c2) VALUES(1111, -2);  -- c2positive
 ERROR:  new row for relation "T 1" violates check constraint "c2positive"
 DETAIL:  Failing row contains (1111, -2, null, null, null, null, ft1       , null).
-CONTEXT:  Remote SQL command: INSERT INTO "S 1"."T 1"("C 1", c2, c3, c4, c5, c6, c7, c8) VALUES ($1, $2, $3, $4, $5, $6, $7, $8)
+CONTEXT:  remote SQL command: INSERT INTO "S 1"."T 1"("C 1", c2, c3, c4, c5, c6, c7, c8) VALUES ($1, $2, $3, $4, $5, $6, $7, $8)
 UPDATE ft1 SET c2 = -c2 WHERE c1 = 1;  -- c2positive
 ERROR:  new row for relation "T 1" violates check constraint "c2positive"
 DETAIL:  Failing row contains (1, -1, 00001_trig_update, 1970-01-02 08:00:00+00, 1970-01-02 00:00:00, 1, 1         , foo).
-CONTEXT:  Remote SQL command: UPDATE "S 1"."T 1" SET c2 = (- c2) WHERE (("C 1" = 1))
+CONTEXT:  remote SQL command: UPDATE "S 1"."T 1" SET c2 = (- c2) WHERE (("C 1" = 1))
 -- Test savepoint/rollback behavior
 select c2, count(*) from ft2 where c2 < 500 group by 1 order by 1;
  c2  | count 
@@ -5909,7 +5909,7 @@ savepoint s3;
 update ft2 set c2 = -2 where c2 = 42 and c1 = 10; -- fail on remote side
 ERROR:  new row for relation "T 1" violates check constraint "c2positive"
 DETAIL:  Failing row contains (10, -2, 00010_trig_update_trig_update, 1970-01-11 08:00:00+00, 1970-01-11 00:00:00, 0, 0         , foo).
-CONTEXT:  Remote SQL command: UPDATE "S 1"."T 1" SET c2 = (-2) WHERE ((c2 = 42)) AND (("C 1" = 10))
+CONTEXT:  remote SQL command: UPDATE "S 1"."T 1" SET c2 = (-2) WHERE ((c2 = 42)) AND (("C 1" = 10))
 rollback to savepoint s3;
 select c2, count(*) from ft2 where c2 < 500 group by 1 order by 1;
  c2  | count 
@@ -6126,11 +6126,11 @@ RESET constraint_exclusion;
 INSERT INTO ft1(c1, c2) VALUES(1111, -2);  -- c2positive
 ERROR:  new row for relation "T 1" violates check constraint "c2positive"
 DETAIL:  Failing row contains (1111, -2, null, null, null, null, ft1       , null).
-CONTEXT:  Remote SQL command: INSERT INTO "S 1"."T 1"("C 1", c2, c3, c4, c5, c6, c7, c8) VALUES ($1, $2, $3, $4, $5, $6, $7, $8)
+CONTEXT:  remote SQL command: INSERT INTO "S 1"."T 1"("C 1", c2, c3, c4, c5, c6, c7, c8) VALUES ($1, $2, $3, $4, $5, $6, $7, $8)
 UPDATE ft1 SET c2 = -c2 WHERE c1 = 1;  -- c2positive
 ERROR:  new row for relation "T 1" violates check constraint "c2positive"
 DETAIL:  Failing row contains (1, -1, 00001_trig_update, 1970-01-02 08:00:00+00, 1970-01-02 00:00:00, 1, 1         , foo).
-CONTEXT:  Remote SQL command: UPDATE "S 1"."T 1" SET c2 = (- c2) WHERE (("C 1" = 1))
+CONTEXT:  remote SQL command: UPDATE "S 1"."T 1" SET c2 = (- c2) WHERE (("C 1" = 1))
 ALTER FOREIGN TABLE ft1 DROP CONSTRAINT ft1_c2positive;
 -- But inconsistent check constraints provide inconsistent results
 ALTER FOREIGN TABLE ft1 ADD CONSTRAINT ft1_c2negative CHECK (c2 < 0);
diff --git a/contrib/postgres_fdw/option.c b/contrib/postgres_fdw/option.c
index 082f79ae04..6854f1bd91 100644
--- a/contrib/postgres_fdw/option.c
+++ b/contrib/postgres_fdw/option.c
@@ -196,7 +196,7 @@ InitPgFdwOptions(void)
 		ereport(ERROR,
 				(errcode(ERRCODE_FDW_OUT_OF_MEMORY),
 				 errmsg("out of memory"),
-				 errdetail("could not get libpq's default connection options")));
+				 errdetail("Could not get libpq's default connection options.")));
 
 	/* Count how many libpq options are available. */
 	num_libpq_opts = 0;
diff --git a/doc/src/sgml/typeconv.sgml b/doc/src/sgml/typeconv.sgml
index cd7de8fe3f..0149b9afea 100644
--- a/doc/src/sgml/typeconv.sgml
+++ b/doc/src/sgml/typeconv.sgml
@@ -453,7 +453,7 @@ try a similar case with <literal>~</literal>, we get:
 SELECT ~ '20' AS "negation";
 
 ERROR:  operator is not unique: ~ "unknown"
-HINT:  Could not choose a best candidate operator. You might need to add
+HINT:  Could not choose a best candidate operator.  You might need to add
 explicit type casts.
 </screen>
 This happens because the system cannot decide which of the several
@@ -805,7 +805,7 @@ the parser will try to convert that to <type>text</type>:
 <screen>
 SELECT substr(1234, 3);
 ERROR:  function substr(integer, integer) does not exist
-HINT:  No function matches the given name and argument types. You might need
+HINT:  No function matches the given name and argument types.  You might need
 to add explicit type casts.
 </screen>
 
diff --git a/src/backend/access/gist/gistsplit.c b/src/backend/access/gist/gistsplit.c
index a7038cca67..10cb380ab1 100644
--- a/src/backend/access/gist/gistsplit.c
+++ b/src/backend/access/gist/gistsplit.c
@@ -445,7 +445,7 @@ gistUserPicksplit(Relation r, GistEntryVector *entryvec, int attno, GistSplitVec
 				(errcode(ERRCODE_INTERNAL_ERROR),
 				 errmsg("picksplit method for column %d of index \"%s\" failed",
 						attno + 1, RelationGetRelationName(r)),
-				 errhint("The index is not optimal. To optimize it, contact a developer, or try to use the column as the second one in the CREATE INDEX command.")));
+				 errhint("The index is not optimal.  To optimize it, contact a developer, or try to use the column as the second one in the CREATE INDEX command.")));
 
 		/*
 		 * Reinit GIST_SPLITVEC. Although these fields are not used by
diff --git a/src/backend/access/nbtree/nbtpage.c b/src/backend/access/nbtree/nbtpage.c
index 92afe2de38..36401ce4ac 100644
--- a/src/backend/access/nbtree/nbtpage.c
+++ b/src/backend/access/nbtree/nbtpage.c
@@ -1153,7 +1153,7 @@ _bt_pagedel(Relation rel, Buffer buf)
 						(errcode(ERRCODE_INDEX_CORRUPTED),
 						 errmsg("index \"%s\" contains a half-dead internal page",
 								RelationGetRelationName(rel)),
-						 errhint("This can be caused by an interrupted VACUUM in version 9.3 or older, before upgrade. Please REINDEX it.")));
+						 errhint("This can be caused by an interrupted VACUUM in version 9.3 or older, before upgrade.  Please REINDEX it.")));
 			_bt_relbuf(rel, buf);
 			return ndeleted;
 		}
diff --git a/src/backend/access/transam/xlog.c b/src/backend/access/transam/xlog.c
index 47a6c4d895..cb9c2a29cb 100644
--- a/src/backend/access/transam/xlog.c
+++ b/src/backend/access/transam/xlog.c
@@ -9328,7 +9328,7 @@ CreateRestartPoint(int flags)
 	ereport((log_checkpoints ? LOG : DEBUG2),
 			(errmsg("recovery restart point at %X/%X",
 					(uint32) (lastCheckPoint.redo >> 32), (uint32) lastCheckPoint.redo),
-			 xtime ? errdetail("last completed transaction was at log time %s",
+			 xtime ? errdetail("Last completed transaction was at log time %s.",
 							   timestamptz_to_str(xtime)) : 0));
 
 	LWLockRelease(CheckpointLock);
diff --git a/src/backend/commands/copy.c b/src/backend/commands/copy.c
index 4562a5121d..ef83c86c68 100644
--- a/src/backend/commands/copy.c
+++ b/src/backend/commands/copy.c
@@ -794,13 +794,13 @@ DoCopy(ParseState *pstate, const CopyStmt *stmt,
 			ereport(ERROR,
 					(errcode(ERRCODE_INSUFFICIENT_PRIVILEGE),
 					 errmsg("must be superuser to COPY to or from an external program"),
-					 errhint("Anyone can COPY to stdout or from stdin. "
+					 errhint("Anyone can COPY to stdout or from stdin.  "
 							 "psql's \\copy command also works for anyone.")));
 		else
 			ereport(ERROR,
 					(errcode(ERRCODE_INSUFFICIENT_PRIVILEGE),
 					 errmsg("must be superuser to COPY to or from a file"),
-					 errhint("Anyone can COPY to stdout or from stdin. "
+					 errhint("Anyone can COPY to stdout or from stdin.  "
 							 "psql's \\copy command also works for anyone.")));
 	}
 
@@ -1843,7 +1843,7 @@ BeginCopyTo(ParseState *pstate,
 						 errmsg("could not open file \"%s\" for writing: %m",
 								cstate->filename),
 						 (save_errno == ENOENT || save_errno == EACCES) ?
-						 errhint("COPY TO instructs the PostgreSQL server process to write a file. "
+						 errhint("COPY TO instructs the PostgreSQL server process to write a file.  "
 								 "You may want a client-side facility such as psql's \\copy.") : 0));
 			}
 
@@ -3084,7 +3084,7 @@ BeginCopyFrom(ParseState *pstate,
 						 errmsg("could not open file \"%s\" for reading: %m",
 								cstate->filename),
 						 (save_errno == ENOENT || save_errno == EACCES) ?
-						 errhint("COPY FROM instructs the PostgreSQL server process to read a file. "
+						 errhint("COPY FROM instructs the PostgreSQL server process to read a file.  "
 								 "You may want a client-side facility such as psql's \\copy.") : 0));
 			}
 
diff --git a/src/backend/parser/analyze.c b/src/backend/parser/analyze.c
index c3a9617f67..0c86c1adf9 100644
--- a/src/backend/parser/analyze.c
+++ b/src/backend/parser/analyze.c
@@ -937,7 +937,7 @@ transformInsertRow(ParseState *pstate, List *exprlist,
 				 ((list_length(exprlist) == 1 &&
 				   count_rowexpr_columns(pstate, linitial(exprlist)) ==
 				   list_length(icolumns)) ?
-				  errhint("The insertion source is a row expression containing the same number of columns expected by the INSERT. Did you accidentally use extra parentheses?") : 0),
+				  errhint("The insertion source is a row expression containing the same number of columns expected by the INSERT.  Did you accidentally use extra parentheses?") : 0),
 				 parser_errposition(pstate,
 									exprLocation(list_nth(icolumns,
 														  list_length(exprlist))))));
diff --git a/src/backend/parser/parse_func.c b/src/backend/parser/parse_func.c
index ea5d5212b4..5495757abe 100644
--- a/src/backend/parser/parse_func.c
+++ b/src/backend/parser/parse_func.c
@@ -530,7 +530,7 @@ ParseFuncOrColumn(ParseState *pstate, List *funcname, List *fargs,
 					 errmsg("function %s is not unique",
 							func_signature_string(funcname, nargs, argnames,
 												  actual_arg_types)),
-					 errhint("Could not choose a best candidate function. "
+					 errhint("Could not choose a best candidate function.  "
 							 "You might need to add explicit type casts."),
 					 parser_errposition(pstate, location)));
 		else if (list_length(agg_order) > 1 && !agg_within_group)
@@ -541,7 +541,7 @@ ParseFuncOrColumn(ParseState *pstate, List *funcname, List *fargs,
 					 errmsg("function %s does not exist",
 							func_signature_string(funcname, nargs, argnames,
 												  actual_arg_types)),
-					 errhint("No aggregate function matches the given name and argument types. "
+					 errhint("No aggregate function matches the given name and argument types.  "
 							 "Perhaps you misplaced ORDER BY; ORDER BY must appear "
 							 "after all regular arguments of the aggregate."),
 					 parser_errposition(pstate, location)));
@@ -552,7 +552,7 @@ ParseFuncOrColumn(ParseState *pstate, List *funcname, List *fargs,
 					 errmsg("function %s does not exist",
 							func_signature_string(funcname, nargs, argnames,
 												  actual_arg_types)),
-					 errhint("No function matches the given name and argument types. "
+					 errhint("No function matches the given name and argument types.  "
 							 "You might need to add explicit type casts."),
 					 parser_errposition(pstate, location)));
 	}
diff --git a/src/backend/parser/parse_oper.c b/src/backend/parser/parse_oper.c
index b279e1236a..dac84a7041 100644
--- a/src/backend/parser/parse_oper.c
+++ b/src/backend/parser/parse_oper.c
@@ -715,7 +715,7 @@ op_error(ParseState *pstate, List *op, char oprkind,
 				(errcode(ERRCODE_AMBIGUOUS_FUNCTION),
 				 errmsg("operator is not unique: %s",
 						op_signature_string(op, oprkind, arg1, arg2)),
-				 errhint("Could not choose a best candidate operator. "
+				 errhint("Could not choose a best candidate operator.  "
 						 "You might need to add explicit type casts."),
 				 parser_errposition(pstate, location)));
 	else
@@ -724,9 +724,9 @@ op_error(ParseState *pstate, List *op, char oprkind,
 				 errmsg("operator does not exist: %s",
 						op_signature_string(op, oprkind, arg1, arg2)),
 				 (!arg1 || !arg2) ?
-				 errhint("No operator matches the given name and argument type. "
+				 errhint("No operator matches the given name and argument type.  "
 						 "You might need to add an explicit type cast.") :
-				 errhint("No operator matches the given name and argument types. "
+				 errhint("No operator matches the given name and argument types.  "
 						 "You might need to add explicit type casts."),
 				 parser_errposition(pstate, location)));
 }
diff --git a/src/backend/replication/logical/logical.c b/src/backend/replication/logical/logical.c
index 7637efc32e..7840229d8a 100644
--- a/src/backend/replication/logical/logical.c
+++ b/src/backend/replication/logical/logical.c
@@ -413,7 +413,7 @@ CreateDecodingContext(XLogRecPtr start_lsn,
 	ereport(LOG,
 			(errmsg("starting logical decoding for slot \"%s\"",
 					NameStr(slot->data.name)),
-			 errdetail("streaming transactions committing after %X/%X, reading WAL from %X/%X",
+			 errdetail("Streaming transactions committing after %X/%X, reading WAL from %X/%X.",
 					   (uint32) (slot->data.confirmed_flush >> 32),
 					   (uint32) slot->data.confirmed_flush,
 					   (uint32) (slot->data.restart_lsn >> 32),
diff --git a/src/backend/tcop/postgres.c b/src/backend/tcop/postgres.c
index 6dc2095b9a..314009ba6d 100644
--- a/src/backend/tcop/postgres.c
+++ b/src/backend/tcop/postgres.c
@@ -2711,7 +2711,7 @@ FloatExceptionHandler(SIGNAL_ARGS)
 	ereport(ERROR,
 			(errcode(ERRCODE_FLOATING_POINT_EXCEPTION),
 			 errmsg("floating-point exception"),
-			 errdetail("An invalid floating-point operation was signaled. "
+			 errdetail("An invalid floating-point operation was signaled.  "
 					   "This probably means an out-of-range result or an "
 					   "invalid operation, such as division by zero.")));
 }
diff --git a/src/pl/plperl/expected/plperl_elog.out b/src/pl/plperl/expected/plperl_elog.out
index a6d35cb79c..2ca8684b6a 100644
--- a/src/pl/plperl/expected/plperl_elog.out
+++ b/src/pl/plperl/expected/plperl_elog.out
@@ -41,7 +41,7 @@ select uses_global();
 ERROR:  function uses_global() does not exist
 LINE 1: select uses_global();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SET plperl.use_strict = false;
 create or replace function uses_global() returns text language plperl as $$
 
diff --git a/src/pl/plperl/expected/plperl_elog_1.out b/src/pl/plperl/expected/plperl_elog_1.out
index 85aa460ec4..c6f18bf06f 100644
--- a/src/pl/plperl/expected/plperl_elog_1.out
+++ b/src/pl/plperl/expected/plperl_elog_1.out
@@ -41,7 +41,7 @@ select uses_global();
 ERROR:  function uses_global() does not exist
 LINE 1: select uses_global();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SET plperl.use_strict = false;
 create or replace function uses_global() returns text language plperl as $$
 
diff --git a/src/pl/plpgsql/src/expected/plpgsql_record.out b/src/pl/plpgsql/src/expected/plpgsql_record.out
index 29e42fda6c..b4c80c0bec 100644
--- a/src/pl/plpgsql/src/expected/plpgsql_record.out
+++ b/src/pl/plpgsql/src/expected/plpgsql_record.out
@@ -336,7 +336,7 @@ select getf1(1);
 ERROR:  function getf1(integer) does not exist
 LINE 1: select getf1(1);
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 select getf1(row(1,2));
  getf1 
 -------
diff --git a/src/pl/plpython/expected/plpython_error.out b/src/pl/plpython/expected/plpython_error.out
index 4d615b41cc..88e8ddf569 100644
--- a/src/pl/plpython/expected/plpython_error.out
+++ b/src/pl/plpython/expected/plpython_error.out
@@ -63,7 +63,7 @@ SELECT exception_index_invalid_nested();
 ERROR:  spiexceptions.UndefinedFunction: function test5(unknown) does not exist
 LINE 1: SELECT test5('foo')
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 QUERY:  SELECT test5('foo')
 CONTEXT:  Traceback (most recent call last):
   PL/Python function "exception_index_invalid_nested", line 1, in <module>
diff --git a/src/pl/plpython/expected/plpython_error_0.out b/src/pl/plpython/expected/plpython_error_0.out
index 290902b182..c788ad8971 100644
--- a/src/pl/plpython/expected/plpython_error_0.out
+++ b/src/pl/plpython/expected/plpython_error_0.out
@@ -63,7 +63,7 @@ SELECT exception_index_invalid_nested();
 ERROR:  spiexceptions.UndefinedFunction: function test5(unknown) does not exist
 LINE 1: SELECT test5('foo')
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 QUERY:  SELECT test5('foo')
 CONTEXT:  Traceback (most recent call last):
   PL/Python function "exception_index_invalid_nested", line 1, in <module>
diff --git a/src/pl/plpython/expected/plpython_error_5.out b/src/pl/plpython/expected/plpython_error_5.out
index bc66ab5534..12b90c3b2d 100644
--- a/src/pl/plpython/expected/plpython_error_5.out
+++ b/src/pl/plpython/expected/plpython_error_5.out
@@ -63,7 +63,7 @@ SELECT exception_index_invalid_nested();
 ERROR:  spiexceptions.UndefinedFunction: function test5(unknown) does not exist
 LINE 1: SELECT test5('foo')
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 QUERY:  SELECT test5('foo')
 CONTEXT:  Traceback (most recent call last):
   PL/Python function "exception_index_invalid_nested", line 1, in <module>
diff --git a/src/pl/plpython/expected/plpython_subtransaction_0.out b/src/pl/plpython/expected/plpython_subtransaction_0.out
index e6cc38a033..021929d8b5 100644
--- a/src/pl/plpython/expected/plpython_subtransaction_0.out
+++ b/src/pl/plpython/expected/plpython_subtransaction_0.out
@@ -86,7 +86,7 @@ SELECT subtransaction_ctx_test();
 ERROR:  function subtransaction_ctx_test() does not exist
 LINE 1: SELECT subtransaction_ctx_test();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT * FROM subtransaction_tbl;
  i 
 ---
@@ -97,7 +97,7 @@ SELECT subtransaction_ctx_test('SPI');
 ERROR:  function subtransaction_ctx_test(unknown) does not exist
 LINE 1: SELECT subtransaction_ctx_test('SPI');
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT * FROM subtransaction_tbl;
  i 
 ---
@@ -108,7 +108,7 @@ SELECT subtransaction_ctx_test('Python');
 ERROR:  function subtransaction_ctx_test(unknown) does not exist
 LINE 1: SELECT subtransaction_ctx_test('Python');
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT * FROM subtransaction_tbl;
  i 
 ---
@@ -137,7 +137,7 @@ SELECT subtransaction_nested_test();
 ERROR:  function subtransaction_nested_test() does not exist
 LINE 1: SELECT subtransaction_nested_test();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT * FROM subtransaction_tbl;
  i 
 ---
@@ -148,7 +148,7 @@ SELECT subtransaction_nested_test('t');
 ERROR:  function subtransaction_nested_test(unknown) does not exist
 LINE 1: SELECT subtransaction_nested_test('t');
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT * FROM subtransaction_tbl;
  i 
 ---
@@ -171,7 +171,7 @@ SELECT subtransaction_deeply_nested_test();
 ERROR:  function subtransaction_deeply_nested_test() does not exist
 LINE 1: SELECT subtransaction_deeply_nested_test();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT * FROM subtransaction_tbl;
  i 
 ---
@@ -272,12 +272,12 @@ SELECT subtransaction_enter_subtransaction_in_with();
 ERROR:  function subtransaction_enter_subtransaction_in_with() does not exist
 LINE 1: SELECT subtransaction_enter_subtransaction_in_with();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT subtransaction_exit_subtransaction_in_with();
 ERROR:  function subtransaction_exit_subtransaction_in_with() does not exist
 LINE 1: SELECT subtransaction_exit_subtransaction_in_with();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 -- Make sure we don't get a "current transaction is aborted" error
 SELECT 1 as test;
  test 
@@ -310,7 +310,7 @@ SELECT subtransaction_mix_explicit_and_implicit();
 ERROR:  function subtransaction_mix_explicit_and_implicit() does not exist
 LINE 1: SELECT subtransaction_mix_explicit_and_implicit();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT * FROM subtransaction_tbl;
  i 
 ---
@@ -346,7 +346,7 @@ SELECT try_catch_inside_subtransaction();
 ERROR:  function try_catch_inside_subtransaction() does not exist
 LINE 1: SELECT try_catch_inside_subtransaction();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT * FROM subtransaction_tbl;
  i 
 ---
@@ -369,7 +369,7 @@ SELECT pk_violation_inside_subtransaction();
 ERROR:  function pk_violation_inside_subtransaction() does not exist
 LINE 1: SELECT pk_violation_inside_subtransaction();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT * FROM subtransaction_tbl;
  i 
 ---
@@ -430,19 +430,19 @@ SELECT cursor_in_subxact();
 ERROR:  function cursor_in_subxact() does not exist
 LINE 1: SELECT cursor_in_subxact();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT cursor_aborted_subxact();
 ERROR:  function cursor_aborted_subxact() does not exist
 LINE 1: SELECT cursor_aborted_subxact();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT cursor_plan_aborted_subxact();
 ERROR:  function cursor_plan_aborted_subxact() does not exist
 LINE 1: SELECT cursor_plan_aborted_subxact();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT cursor_close_aborted_subxact();
 ERROR:  function cursor_close_aborted_subxact() does not exist
 LINE 1: SELECT cursor_close_aborted_subxact();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
diff --git a/src/pl/plpython/expected/plpython_subtransaction_5.out b/src/pl/plpython/expected/plpython_subtransaction_5.out
index 6fbafa3166..71f20fbf8f 100644
--- a/src/pl/plpython/expected/plpython_subtransaction_5.out
+++ b/src/pl/plpython/expected/plpython_subtransaction_5.out
@@ -86,7 +86,7 @@ SELECT subtransaction_ctx_test();
 ERROR:  function subtransaction_ctx_test() does not exist
 LINE 1: SELECT subtransaction_ctx_test();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT * FROM subtransaction_tbl;
  i 
 ---
@@ -97,7 +97,7 @@ SELECT subtransaction_ctx_test('SPI');
 ERROR:  function subtransaction_ctx_test(unknown) does not exist
 LINE 1: SELECT subtransaction_ctx_test('SPI');
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT * FROM subtransaction_tbl;
  i 
 ---
@@ -108,7 +108,7 @@ SELECT subtransaction_ctx_test('Python');
 ERROR:  function subtransaction_ctx_test(unknown) does not exist
 LINE 1: SELECT subtransaction_ctx_test('Python');
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT * FROM subtransaction_tbl;
  i 
 ---
@@ -137,7 +137,7 @@ SELECT subtransaction_nested_test();
 ERROR:  function subtransaction_nested_test() does not exist
 LINE 1: SELECT subtransaction_nested_test();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT * FROM subtransaction_tbl;
  i 
 ---
@@ -148,7 +148,7 @@ SELECT subtransaction_nested_test('t');
 ERROR:  function subtransaction_nested_test(unknown) does not exist
 LINE 1: SELECT subtransaction_nested_test('t');
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT * FROM subtransaction_tbl;
  i 
 ---
@@ -171,7 +171,7 @@ SELECT subtransaction_deeply_nested_test();
 ERROR:  function subtransaction_deeply_nested_test() does not exist
 LINE 1: SELECT subtransaction_deeply_nested_test();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT * FROM subtransaction_tbl;
  i 
 ---
@@ -272,12 +272,12 @@ SELECT subtransaction_enter_subtransaction_in_with();
 ERROR:  function subtransaction_enter_subtransaction_in_with() does not exist
 LINE 1: SELECT subtransaction_enter_subtransaction_in_with();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT subtransaction_exit_subtransaction_in_with();
 ERROR:  function subtransaction_exit_subtransaction_in_with() does not exist
 LINE 1: SELECT subtransaction_exit_subtransaction_in_with();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 -- Make sure we don't get a "current transaction is aborted" error
 SELECT 1 as test;
  test 
@@ -310,7 +310,7 @@ SELECT subtransaction_mix_explicit_and_implicit();
 ERROR:  function subtransaction_mix_explicit_and_implicit() does not exist
 LINE 1: SELECT subtransaction_mix_explicit_and_implicit();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT * FROM subtransaction_tbl;
  i 
 ---
@@ -346,7 +346,7 @@ SELECT try_catch_inside_subtransaction();
 ERROR:  function try_catch_inside_subtransaction() does not exist
 LINE 1: SELECT try_catch_inside_subtransaction();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT * FROM subtransaction_tbl;
  i 
 ---
@@ -369,7 +369,7 @@ SELECT pk_violation_inside_subtransaction();
 ERROR:  function pk_violation_inside_subtransaction() does not exist
 LINE 1: SELECT pk_violation_inside_subtransaction();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT * FROM subtransaction_tbl;
  i 
 ---
@@ -430,19 +430,19 @@ SELECT cursor_in_subxact();
 ERROR:  function cursor_in_subxact() does not exist
 LINE 1: SELECT cursor_in_subxact();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT cursor_aborted_subxact();
 ERROR:  function cursor_aborted_subxact() does not exist
 LINE 1: SELECT cursor_aborted_subxact();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT cursor_plan_aborted_subxact();
 ERROR:  function cursor_plan_aborted_subxact() does not exist
 LINE 1: SELECT cursor_plan_aborted_subxact();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT cursor_close_aborted_subxact();
 ERROR:  function cursor_close_aborted_subxact() does not exist
 LINE 1: SELECT cursor_close_aborted_subxact();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
diff --git a/src/test/regress/expected/alter_table.out b/src/test/regress/expected/alter_table.out
index a80d16a394..483e9def86 100644
--- a/src/test/regress/expected/alter_table.out
+++ b/src/test/regress/expected/alter_table.out
@@ -1934,7 +1934,7 @@ alter table anothertab alter column atcol1 drop default;
 alter table anothertab alter column atcol1 type boolean
         using case when atcol1 % 2 = 0 then true else false end; -- fails
 ERROR:  operator does not exist: boolean <= integer
-HINT:  No operator matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No operator matches the given name and argument types.  You might need to add explicit type casts.
 alter table anothertab drop constraint anothertab_chk;
 alter table anothertab drop constraint anothertab_chk; -- fails
 ERROR:  constraint "anothertab_chk" of relation "anothertab" does not exist
diff --git a/src/test/regress/expected/arrays.out b/src/test/regress/expected/arrays.out
index c730563f03..6eecb3d610 100644
--- a/src/test/regress/expected/arrays.out
+++ b/src/test/regress/expected/arrays.out
@@ -2259,7 +2259,7 @@ SELECT width_bucket('5'::text, ARRAY[3, 4]::integer[]);
 ERROR:  function width_bucket(text, integer[]) does not exist
 LINE 1: SELECT width_bucket('5'::text, ARRAY[3, 4]::integer[]);
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT width_bucket(5, ARRAY[3, 4, NULL]);
 ERROR:  thresholds array must not contain NULLs
 SELECT width_bucket(5, ARRAY[ARRAY[1, 2], ARRAY[3, 4]]);
diff --git a/src/test/regress/expected/create_cast.out b/src/test/regress/expected/create_cast.out
index 88f94a63b4..7815f97597 100644
--- a/src/test/regress/expected/create_cast.out
+++ b/src/test/regress/expected/create_cast.out
@@ -26,14 +26,14 @@ SELECT casttestfunc('foo'::text); -- fails, as there's no cast
 ERROR:  function casttestfunc(text) does not exist
 LINE 1: SELECT casttestfunc('foo'::text);
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 -- Try binary coercion cast
 CREATE CAST (text AS casttesttype) WITHOUT FUNCTION;
 SELECT casttestfunc('foo'::text); -- doesn't work, as the cast is explicit
 ERROR:  function casttestfunc(text) does not exist
 LINE 1: SELECT casttestfunc('foo'::text);
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT casttestfunc('foo'::text::casttesttype); -- should work
  casttestfunc 
 --------------
diff --git a/src/test/regress/expected/create_procedure.out b/src/test/regress/expected/create_procedure.out
index dacb657706..aae101dc67 100644
--- a/src/test/regress/expected/create_procedure.out
+++ b/src/test/regress/expected/create_procedure.out
@@ -2,7 +2,7 @@ CALL nonexistent();  -- error
 ERROR:  function nonexistent() does not exist
 LINE 1: CALL nonexistent();
              ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 CALL random();  -- error
 ERROR:  random() is not a procedure
 LINE 1: CALL random();
diff --git a/src/test/regress/expected/create_view.out b/src/test/regress/expected/create_view.out
index 141fc6da62..5d2d1fa7d6 100644
--- a/src/test/regress/expected/create_view.out
+++ b/src/test/regress/expected/create_view.out
@@ -1605,7 +1605,7 @@ select 'foo'::text = any((select array['abc','def','foo']::text[]));  -- fail
 ERROR:  operator does not exist: text = text[]
 LINE 1: select 'foo'::text = any((select array['abc','def','foo']::t...
                            ^
-HINT:  No operator matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No operator matches the given name and argument types.  You might need to add explicit type casts.
 select 'foo'::text = any((select array['abc','def','foo']::text[])::text[]);
  ?column? 
 ----------
diff --git a/src/test/regress/expected/domain.out b/src/test/regress/expected/domain.out
index f4eebb75cf..75777b58af 100644
--- a/src/test/regress/expected/domain.out
+++ b/src/test/regress/expected/domain.out
@@ -295,7 +295,7 @@ select row(0,1)::dcomptype;  -- fail
 ERROR:  value for domain dcomptype violates check constraint "c1"
 alter type comptype alter attribute r type varchar;  -- fail
 ERROR:  operator does not exist: character varying > double precision
-HINT:  No operator matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No operator matches the given name and argument types.  You might need to add explicit type casts.
 alter type comptype alter attribute r type bigint;
 alter type comptype drop attribute r;  -- fail
 ERROR:  cannot drop composite type comptype column r because other objects depend on it
diff --git a/src/test/regress/expected/geometry.out b/src/test/regress/expected/geometry.out
index e4c0039040..9d9f524126 100644
--- a/src/test/regress/expected/geometry.out
+++ b/src/test/regress/expected/geometry.out
@@ -107,7 +107,7 @@ SELECT '' AS count, p.f1, l.s, l.s # p.f1 AS intersection
 ERROR:  operator does not exist: lseg # point
 LINE 1: SELECT '' AS count, p.f1, l.s, l.s # p.f1 AS intersection
                                            ^
-HINT:  No operator matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No operator matches the given name and argument types.  You might need to add explicit type casts.
 -- closest point
 SELECT '' AS thirty, p.f1, l.s, p.f1 ## l.s AS closest
    FROM LSEG_TBL l, POINT_TBL p;
diff --git a/src/test/regress/expected/geometry_1.out b/src/test/regress/expected/geometry_1.out
index 3b92e23059..3ff1159894 100644
--- a/src/test/regress/expected/geometry_1.out
+++ b/src/test/regress/expected/geometry_1.out
@@ -107,7 +107,7 @@ SELECT '' AS count, p.f1, l.s, l.s # p.f1 AS intersection
 ERROR:  operator does not exist: lseg # point
 LINE 1: SELECT '' AS count, p.f1, l.s, l.s # p.f1 AS intersection
                                            ^
-HINT:  No operator matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No operator matches the given name and argument types.  You might need to add explicit type casts.
 -- closest point
 SELECT '' AS thirty, p.f1, l.s, p.f1 ## l.s AS closest
    FROM LSEG_TBL l, POINT_TBL p;
diff --git a/src/test/regress/expected/geometry_2.out b/src/test/regress/expected/geometry_2.out
index 5a922bcd3f..44002f6ab4 100644
--- a/src/test/regress/expected/geometry_2.out
+++ b/src/test/regress/expected/geometry_2.out
@@ -107,7 +107,7 @@ SELECT '' AS count, p.f1, l.s, l.s # p.f1 AS intersection
 ERROR:  operator does not exist: lseg # point
 LINE 1: SELECT '' AS count, p.f1, l.s, l.s # p.f1 AS intersection
                                            ^
-HINT:  No operator matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No operator matches the given name and argument types.  You might need to add explicit type casts.
 -- closest point
 SELECT '' AS thirty, p.f1, l.s, p.f1 ## l.s AS closest
    FROM LSEG_TBL l, POINT_TBL p;
diff --git a/src/test/regress/expected/horology.out b/src/test/regress/expected/horology.out
index 63e39198e6..809d062b09 100644
--- a/src/test/regress/expected/horology.out
+++ b/src/test/regress/expected/horology.out
@@ -321,7 +321,7 @@ SELECT date '1991-02-03' - time with time zone '04:05:06 UTC' AS "Subtract Time
 ERROR:  operator does not exist: date - time with time zone
 LINE 1: SELECT date '1991-02-03' - time with time zone '04:05:06 UTC...
                                  ^
-HINT:  No operator matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No operator matches the given name and argument types.  You might need to add explicit type casts.
 --
 -- timestamp, interval arithmetic
 --
diff --git a/src/test/regress/expected/misc_functions.out b/src/test/regress/expected/misc_functions.out
index 130a0e4be3..f5f658d06a 100644
--- a/src/test/regress/expected/misc_functions.out
+++ b/src/test/regress/expected/misc_functions.out
@@ -127,9 +127,9 @@ SELECT num_nonnulls();
 ERROR:  function num_nonnulls() does not exist
 LINE 1: SELECT num_nonnulls();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 SELECT num_nulls();
 ERROR:  function num_nulls() does not exist
 LINE 1: SELECT num_nulls();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
diff --git a/src/test/regress/expected/plpgsql.out b/src/test/regress/expected/plpgsql.out
index b687fbfddc..40eae0e699 100644
--- a/src/test/regress/expected/plpgsql.out
+++ b/src/test/regress/expected/plpgsql.out
@@ -3101,7 +3101,7 @@ select shadowtest(1);
 ERROR:  function shadowtest(integer) does not exist
 LINE 1: select shadowtest(1);
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 reset plpgsql.extra_errors;
 reset plpgsql.extra_warnings;
 create or replace function shadowtest(f1 int)
diff --git a/src/test/regress/expected/polymorphism.out b/src/test/regress/expected/polymorphism.out
index 67e70c8c14..a989df4646 100644
--- a/src/test/regress/expected/polymorphism.out
+++ b/src/test/regress/expected/polymorphism.out
@@ -728,7 +728,7 @@ select myleast(); -- fail
 ERROR:  function myleast() does not exist
 LINE 1: select myleast();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 -- test with variadic call parameter
 select myleast(variadic array[1,2,3,4,-1]);
  myleast 
@@ -798,17 +798,17 @@ select formarray(1.1, array[1.2,55.5]); -- fail without variadic
 ERROR:  function formarray(numeric, numeric[]) does not exist
 LINE 1: select formarray(1.1, array[1.2,55.5]);
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 select formarray(1, 'x'::text); -- fail, type mismatch
 ERROR:  function formarray(integer, text) does not exist
 LINE 1: select formarray(1, 'x'::text);
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 select formarray(1, variadic array['x'::text]); -- fail, type mismatch
 ERROR:  function formarray(integer, text[]) does not exist
 LINE 1: select formarray(1, variadic array['x'::text]);
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 drop function formarray(anyelement, variadic anyarray);
 -- test pg_typeof() function
 select pg_typeof(null);           -- unknown
@@ -892,7 +892,7 @@ select dfunc(10, 20, 30);  -- fail
 ERROR:  function dfunc(integer, integer, integer) does not exist
 LINE 1: select dfunc(10, 20, 30);
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 drop function dfunc();  -- fail
 ERROR:  function dfunc() does not exist
 drop function dfunc(int);  -- fail
@@ -939,7 +939,7 @@ select dfunc();  -- fail: which dfunc should be called? int or text
 ERROR:  function dfunc() is not unique
 LINE 1: select dfunc();
                ^
-HINT:  Could not choose a best candidate function. You might need to add explicit type casts.
+HINT:  Could not choose a best candidate function.  You might need to add explicit type casts.
 select dfunc('Hi');  -- ok
    dfunc   
 -----------
@@ -978,17 +978,17 @@ select dfunc();  -- fail
 ERROR:  function dfunc() is not unique
 LINE 1: select dfunc();
                ^
-HINT:  Could not choose a best candidate function. You might need to add explicit type casts.
+HINT:  Could not choose a best candidate function.  You might need to add explicit type casts.
 select dfunc(1);  -- fail
 ERROR:  function dfunc(integer) is not unique
 LINE 1: select dfunc(1);
                ^
-HINT:  Could not choose a best candidate function. You might need to add explicit type casts.
+HINT:  Could not choose a best candidate function.  You might need to add explicit type casts.
 select dfunc(1, 2);  -- fail
 ERROR:  function dfunc(integer, integer) is not unique
 LINE 1: select dfunc(1, 2);
                ^
-HINT:  Could not choose a best candidate function. You might need to add explicit type casts.
+HINT:  Could not choose a best candidate function.  You might need to add explicit type casts.
 select dfunc(1, 2, 3);  -- ok
  dfunc 
 -------
@@ -1044,7 +1044,7 @@ select dfunc();  -- fail
 ERROR:  function dfunc() does not exist
 LINE 1: select dfunc();
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 select dfunc(10);
  dfunc 
 -------
@@ -1105,7 +1105,7 @@ select dfunc(1);  -- fail
 ERROR:  function dfunc(integer) is not unique
 LINE 1: select dfunc(1);
                ^
-HINT:  Could not choose a best candidate function. You might need to add explicit type casts.
+HINT:  Could not choose a best candidate function.  You might need to add explicit type casts.
 -- but this works since the ambiguous functions aren't preferred anyway
 select dfunc('Hi');
  dfunc 
@@ -1151,7 +1151,7 @@ select * from dfunc(0);  -- fail
 ERROR:  function dfunc(integer) does not exist
 LINE 1: select * from dfunc(0);
                       ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 select * from dfunc(1,2);
  a | b | c | d 
 ---+---+---+---
@@ -1182,17 +1182,17 @@ select * from dfunc(x := 10, b := 20, c := 30);  -- fail, unknown param
 ERROR:  function dfunc(x => integer, b => integer, c => integer) does not exist
 LINE 1: select * from dfunc(x := 10, b := 20, c := 30);
                       ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 select * from dfunc(10, 10, a := 20);  -- fail, a overlaps positional parameter
 ERROR:  function dfunc(integer, integer, a => integer) does not exist
 LINE 1: select * from dfunc(10, 10, a := 20);
                       ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 select * from dfunc(1,c := 2,d := 3); -- fail, no value for b
 ERROR:  function dfunc(integer, c => integer, d => integer) does not exist
 LINE 1: select * from dfunc(1,c := 2,d := 3);
                       ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 drop function dfunc(int, int, int, int);
 -- test with different parameter types
 create function dfunc(a varchar, b numeric, c date = current_date)
@@ -1233,7 +1233,7 @@ select * from dfunc('Hello World', c := 20, b := '2009-07-25'::date);  -- fail
 ERROR:  function dfunc(unknown, c => integer, b => date) does not exist
 LINE 1: select * from dfunc('Hello World', c := 20, b := '2009-07-25...
                       ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 drop function dfunc(varchar, numeric, date);
 -- test out parameters with named params
 create function dfunc(a varchar = 'def a', out _a varchar, c numeric = NULL, out _c numeric)
diff --git a/src/test/regress/expected/rangetypes.out b/src/test/regress/expected/rangetypes.out
index accf1e0d9e..e75db58107 100644
--- a/src/test/regress/expected/rangetypes.out
+++ b/src/test/regress/expected/rangetypes.out
@@ -1254,7 +1254,7 @@ select anyarray_anyrange_func(ARRAY[1,2], numrange(10,20));
 ERROR:  function anyarray_anyrange_func(integer[], numrange) does not exist
 LINE 1: select anyarray_anyrange_func(ARRAY[1,2], numrange(10,20));
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 drop function anyarray_anyrange_func(anyarray, anyrange);
 -- should fail
 create function bogus_func(anyelement)
@@ -1293,7 +1293,7 @@ select rangetypes_sql(numrange(1,10), ARRAY[2,20]);  -- match failure
 ERROR:  function rangetypes_sql(numrange, integer[]) does not exist
 LINE 1: select rangetypes_sql(numrange(1,10), ARRAY[2,20]);
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 --
 -- Arrays of ranges
 --
diff --git a/src/test/regress/expected/rowtypes.out b/src/test/regress/expected/rowtypes.out
index 45cb6ff3da..f94f5823b0 100644
--- a/src/test/regress/expected/rowtypes.out
+++ b/src/test/regress/expected/rowtypes.out
@@ -770,7 +770,7 @@ select text(fullname) from fullname;  -- error
 ERROR:  function text(fullname) does not exist
 LINE 1: select text(fullname) from fullname;
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 select fullname.text from fullname;  -- error
 ERROR:  column fullname.text does not exist
 LINE 1: select fullname.text from fullname;
@@ -792,7 +792,7 @@ select text(row('Jim', 'Beam'));  -- error
 ERROR:  function text(record) does not exist
 LINE 1: select text(row('Jim', 'Beam'));
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 select (row('Jim', 'Beam')).text;  -- error
 ERROR:  could not identify column "text" in record data type
 LINE 1: select (row('Jim', 'Beam')).text;
diff --git a/src/test/regress/expected/text.out b/src/test/regress/expected/text.out
index d28961cf88..a277bd5022 100644
--- a/src/test/regress/expected/text.out
+++ b/src/test/regress/expected/text.out
@@ -29,7 +29,7 @@ select length(42);
 ERROR:  function length(integer) does not exist
 LINE 1: select length(42);
                ^
-HINT:  No function matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No function matches the given name and argument types.  You might need to add explicit type casts.
 -- But as a special exception for usability's sake, we still allow implicit
 -- casting to text in concatenations, so long as the other input is text or
 -- an unknown literal.  So these work:
@@ -50,7 +50,7 @@ select 3 || 4.0;
 ERROR:  operator does not exist: integer || numeric
 LINE 1: select 3 || 4.0;
                  ^
-HINT:  No operator matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No operator matches the given name and argument types.  You might need to add explicit type casts.
 /*
  * various string functions
  */
diff --git a/src/test/regress/expected/time.out b/src/test/regress/expected/time.out
index 8e0afe69e0..03cbe4073d 100644
--- a/src/test/regress/expected/time.out
+++ b/src/test/regress/expected/time.out
@@ -85,4 +85,4 @@ SELECT f1 + time '00:01' AS "Illegal" FROM TIME_TBL;
 ERROR:  operator is not unique: time without time zone + time without time zone
 LINE 1: SELECT f1 + time '00:01' AS "Illegal" FROM TIME_TBL;
                   ^
-HINT:  Could not choose a best candidate operator. You might need to add explicit type casts.
+HINT:  Could not choose a best candidate operator.  You might need to add explicit type casts.
diff --git a/src/test/regress/expected/timetz.out b/src/test/regress/expected/timetz.out
index 33ff8e18c9..a6cdac3132 100644
--- a/src/test/regress/expected/timetz.out
+++ b/src/test/regress/expected/timetz.out
@@ -92,4 +92,4 @@ SELECT f1 + time with time zone '00:01' AS "Illegal" FROM TIMETZ_TBL;
 ERROR:  operator does not exist: time with time zone + time with time zone
 LINE 1: SELECT f1 + time with time zone '00:01' AS "Illegal" FROM TI...
                   ^
-HINT:  No operator matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No operator matches the given name and argument types.  You might need to add explicit type casts.
diff --git a/src/test/regress/expected/with.out b/src/test/regress/expected/with.out
index 2a2085556b..c110b0b89a 100644
--- a/src/test/regress/expected/with.out
+++ b/src/test/regress/expected/with.out
@@ -166,7 +166,7 @@ SELECT n, n IS OF (int) AS is_int FROM t;
 ERROR:  operator does not exist: text + integer
 LINE 4:     SELECT n+1 FROM t WHERE n < 10
                     ^
-HINT:  No operator matches the given name and argument types. You might need to add explicit type casts.
+HINT:  No operator matches the given name and argument types.  You might need to add explicit type casts.
 --
 -- Some examples with a tree
 --
-- 
2.14.1.145.gb3622a4ee

